==> qtjambi-webenginewidgets-debuginfo-macos-5.15.17.jar: sources/QtJambiWebEngineWidgets/QWebEngineFullScreenRequest_shell.cpp <==
#include <QtCore/QtGlobal>
#include <QtWebEngineWidgets/qwebenginefullscreenrequest.h>
#include <QtCore/QVariant>
#include <QtCore/qurl.h>

#include <QtJambi/QtJambiAPI>
#include <QtJambi/RegistryAPI>
#include <QtJambi/Cast>

void deleter_QWebEngineFullScreenRequest(void *ptr, bool isShell)
{
    QTJAMBI_NATIVE_METHOD_CALL("qtjambi_deleter for QWebEngineFullScreenRequest")
    QWebEngineFullScreenRequest *_ptr = reinterpret_cast<QWebEngineFullScreenRequest *>(ptr);
    if(!isShell){
        QtJambiAPI::registerNonShellDeletion(ptr);
    }
    delete _ptr;
}

// emitting (writeConstructors)
// emitting  (functionsInTargetLang writeFinalFunction)
// QWebEngineFullScreenRequest::accept()
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_webengine_widgets_QWebEngineFullScreenRequest_accept_1native__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    QTJAMBI_TRY {
        QWebEngineFullScreenRequest *__qt_this = QtJambiAPI::objectFromNativeId<QWebEngineFullScreenRequest>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QWebEngineFullScreenRequest::accept()", __qt_this)
        __qt_this->accept();
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QWebEngineFullScreenRequest::origin()const
extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_webengine_widgets_QWebEngineFullScreenRequest_origin_1native_1constfct__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jobject __java_return_value{0};
    QTJAMBI_TRY {
        const QWebEngineFullScreenRequest *__qt_this = QtJambiAPI::objectFromNativeId<QWebEngineFullScreenRequest>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QWebEngineFullScreenRequest::origin()const", __qt_this)
        const QUrl& __qt_return_value = __qt_this->origin();
        __java_return_value = qtjambi_cast<jobject>(__jni_env, __qt_return_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QWebEngineFullScreenRequest::reject()
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_webengine_widgets_QWebEngineFullScreenRequest_reject_1native__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    QTJAMBI_TRY {
        QWebEngineFullScreenRequest *__qt_this = QtJambiAPI::objectFromNativeId<QWebEngineFullScreenRequest>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QWebEngineFullScreenRequest::reject()", __qt_this)
        __qt_this->reject();
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QWebEngineFullScreenRequest::toggleOn()const
extern "C" Q_DECL_EXPORT jboolean JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_webengine_widgets_QWebEngineFullScreenRequest_toggleOn_1native_1constfct__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jboolean __java_return_value{0};
    QTJAMBI_TRY {
        const QWebEngineFullScreenRequest *__qt_this = QtJambiAPI::objectFromNativeId<QWebEngineFullScreenRequest>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QWebEngineFullScreenRequest::toggleOn()const", __qt_this)
        __java_return_value = __qt_this->toggleOn();
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// emitting (writeJavaLangObjectOverrideFunctions)
// emitting (writeCloneFunction)

extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_webengine_widgets_QWebEngineFullScreenRequest_clone_1native)
(JNIEnv *__jni_env, jobject, QtJambiNativeID __this_nativeId)
{
    jobject __java_return_value = nullptr;
    QTJAMBI_TRY {
        const QWebEngineFullScreenRequest *__qt_this = QtJambiAPI::objectFromNativeId<QWebEngineFullScreenRequest>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        __java_return_value = QtJambiAPI::convertNativeToJavaOwnedObjectAsWrapper(__jni_env, new QWebEngineFullScreenRequest(*__qt_this));
    } QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    } QTJAMBI_TRY_END
    return __java_return_value;
}


void initialize_meta_info_QWebEngineFullScreenRequest(){
    using namespace RegistryAPI;
    const std::type_info& typeId = registerObjectTypeInfo<QWebEngineFullScreenRequest>("QWebEngineFullScreenRequest", "io/qt/webengine/widgets/QWebEngineFullScreenRequest");
// BEGIN: function table
// END: function table

    registerMetaObject(typeId, QWebEngineFullScreenRequest::staticMetaObject, false,
            {},
            [](const QMetaMethod& method, QList<ParameterInfo>& infos) {
                Q_UNUSED(infos)
                int methodIndex = method.methodIndex();
                if(methodIndex==QWebEngineFullScreenRequest::staticMetaObject.indexOfMethod("accept()")){
                    infos << ParameterInfo(QMetaType::Void);
                    return true;
                }
                if(methodIndex==QWebEngineFullScreenRequest::staticMetaObject.indexOfMethod("reject()")){
                    infos << ParameterInfo(QMetaType::Void);
                    return true;
                }
                return false;
            });
// END: signal table

// BEGIN: type registration
    registerDeleter(typeId, &deleter_QWebEngineFullScreenRequest);
// END: type registration

// BEGIN: polymorphic ids
// END: polymorphic ids


// BEGIN: enums and flags
// END: enums and flags
}

==> qtjambi-webenginewidgets-debuginfo-macos-5.15.20.jar: sources/QtJambiWebEngineWidgets/QWebEngineFullScreenRequest_shell.cpp <==
#include <QtCore/QtGlobal>
#include <QtWebEngineWidgets/qwebenginefullscreenrequest.h>
#include <QtCore/QVariant>
#include <QtCore/qurl.h>

#include <QtJambi/QtJambiAPI>
#include <QtJambi/RegistryAPI>
#include <QtJambi/Cast>

void deleter_QWebEngineFullScreenRequest(void *ptr, bool isShell)
{
    QTJAMBI_NATIVE_METHOD_CALL("qtjambi_deleter for QWebEngineFullScreenRequest")
    QWebEngineFullScreenRequest *_ptr = reinterpret_cast<QWebEngineFullScreenRequest *>(ptr);
    if(!isShell){
        QtJambiAPI::registerNonShellDeletion(ptr);
    }
    delete _ptr;
}

// emitting (writeConstructors)
// new QWebEngineFullScreenRequest(QWebEngineFullScreenRequest)
void __qt_construct_QWebEngineFullScreenRequest_cref_QWebEngineFullScreenRequest(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments, bool __qtjambi_is_generic)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct QWebEngineFullScreenRequest(QWebEngineFullScreenRequest)")
    jobject other0 = __java_arguments[0].l;
    const QWebEngineFullScreenRequest& __qt_other0 = qtjambi_cast<const QWebEngineFullScreenRequest& >(__jni_env, other0);
    QWebEngineFullScreenRequest *__qt_this = new(__qtjambi_ptr) QWebEngineFullScreenRequest(__qt_other0);
    Q_UNUSED(__qtjambi_is_generic)
    Q_UNUSED(__jni_object)
    Q_UNUSED(__qt_this)
}

// QWebEngineFullScreenRequest::QWebEngineFullScreenRequest(QWebEngineFullScreenRequest)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_webengine_widgets_QWebEngineFullScreenRequest_initialize_1native__Lio_qt_webengine_widgets_QWebEngineFullScreenRequest_2Lio_qt_webengine_widgets_QWebEngineFullScreenRequest_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object,
 jobject other0)
{
    QTJAMBI_NATIVE_METHOD_CALL("QWebEngineFullScreenRequest::QWebEngineFullScreenRequest(QWebEngineFullScreenRequest)")
    QTJAMBI_TRY {
        jvalue arguments;
        arguments.l = other0;
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QWebEngineFullScreenRequest_cref_QWebEngineFullScreenRequest, sizeof(QWebEngineFullScreenRequest), typeid(QWebEngineFullScreenRequest), false, &deleter_QWebEngineFullScreenRequest, &arguments);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// emitting  (functionsInTargetLang writeFinalFunction)
// QWebEngineFullScreenRequest::accept()
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_webengine_widgets_QWebEngineFullScreenRequest_accept_1native__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    QTJAMBI_TRY {
        QWebEngineFullScreenRequest *__qt_this = QtJambiAPI::objectFromNativeId<QWebEngineFullScreenRequest>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QWebEngineFullScreenRequest::accept()", __qt_this)
        __qt_this->accept();
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QWebEngineFullScreenRequest::origin()const
extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_webengine_widgets_QWebEngineFullScreenRequest_origin_1native_1constfct__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jobject __java_return_value{0};
    QTJAMBI_TRY {
        const QWebEngineFullScreenRequest *__qt_this = QtJambiAPI::objectFromNativeId<QWebEngineFullScreenRequest>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QWebEngineFullScreenRequest::origin()const", __qt_this)
        const QUrl& __qt_return_value = __qt_this->origin();
        __java_return_value = qtjambi_cast<jobject>(__jni_env, __qt_return_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QWebEngineFullScreenRequest::reject()
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_webengine_widgets_QWebEngineFullScreenRequest_reject_1native__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    QTJAMBI_TRY {
        QWebEngineFullScreenRequest *__qt_this = QtJambiAPI::objectFromNativeId<QWebEngineFullScreenRequest>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QWebEngineFullScreenRequest::reject()", __qt_this)
        __qt_this->reject();
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QWebEngineFullScreenRequest::toggleOn()const
extern "C" Q_DECL_EXPORT jboolean JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_webengine_widgets_QWebEngineFullScreenRequest_toggleOn_1native_1constfct__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jboolean __java_return_value{0};
    QTJAMBI_TRY {
        const QWebEngineFullScreenRequest *__qt_this = QtJambiAPI::objectFromNativeId<QWebEngineFullScreenRequest>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QWebEngineFullScreenRequest::toggleOn()const", __qt_this)
        __java_return_value = __qt_this->toggleOn();
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// emitting (writeJavaLangObjectOverrideFunctions)
// emitting (writeCloneFunction)

extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_webengine_widgets_QWebEngineFullScreenRequest_clone_1native)
(JNIEnv *__jni_env, jobject, QtJambiNativeID __this_nativeId)
{
    jobject __java_return_value = nullptr;
    QTJAMBI_TRY {
        const QWebEngineFullScreenRequest *__qt_this = QtJambiAPI::objectFromNativeId<QWebEngineFullScreenRequest>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        __java_return_value = QtJambiAPI::convertNativeToJavaOwnedObjectAsWrapper(__jni_env, new QWebEngineFullScreenRequest(*__qt_this));
    } QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    } QTJAMBI_TRY_END
    return __java_return_value;
}


void initialize_meta_info_QWebEngineFullScreenRequest(){
    using namespace RegistryAPI;
    const std::type_info& typeId = registerObjectTypeInfo<QWebEngineFullScreenRequest>("QWebEngineFullScreenRequest", "io/qt/webengine/widgets/QWebEngineFullScreenRequest");
// BEGIN: function table
// END: function table

    registerMetaObject(typeId, QWebEngineFullScreenRequest::staticMetaObject, false,
            {},
            [](const QMetaMethod& method, QList<ParameterInfo>& infos) {
                Q_UNUSED(infos)
                int methodIndex = method.methodIndex();
                if(methodIndex==QWebEngineFullScreenRequest::staticMetaObject.indexOfMethod("accept()")){
                    infos << ParameterInfo(QMetaType::Void);
                    return true;
                }
                if(methodIndex==QWebEngineFullScreenRequest::staticMetaObject.indexOfMethod("reject()")){
                    infos << ParameterInfo(QMetaType::Void);
                    return true;
                }
                return false;
            });
// END: signal table

// BEGIN: type registration
    registerDeleter(typeId, &deleter_QWebEngineFullScreenRequest);
// END: type registration

// BEGIN: polymorphic ids
// END: polymorphic ids


// BEGIN: enums and flags
// END: enums and flags
}
